@@ -9,6 +9,7 @@ from socket import getfqdn
 ERROR = PYNETSYS
 
 __version__ = []
+__author__ = "Andrea Vaccaro ANDRVV"
 
 tool, packet = _tool, _packet
 
@@ -27,24 +28,23 @@ def hasWebProtocol(Address: str):
         return False
 
 def addWebProtocol(Address: str, SSL: int = False):
+    # RETURN
     if hasWebProtocol(Address):
         raise ERROR("Already have a web protocol.")    
     else:
         if SSL == True:
-            return f"https:\\\\{Address}\\"
+            return f"https://{Address}/"
         else:
-            return f"http:\\\\{Address}\\"
+            return f"http://{Address}/"
 
 def removeWebProtocol(Address: str):
-    if hasWebProtocol(Address):
-        return Address.replace("http:\\\\", "").replace("https:\\\\", "").replace("\\", "")
+    # RETURN
+    if hasWebProtocol(Address) or hasSSLWebProtocol(Address):
+        return Address.replace("http://", "").replace("https://", "").replace("/", "")
     else:
         raise ERROR("There is not a web protocol.")    
 
 def isOnline(Address: str):
-    # IMPORT
-    from scapy.layers.inet import IP
-
     # RUN & RETURN
     try:
         if get(getfqdn(Address)).status_code == 200:
